import { GetAccountInfoApi, GetMinimumBalanceForRentExemptionApi, Rpc } from '@solana/web3.js';
import { Pool, TakerSide } from '../generated';
/**
 * Returns the amount of lamports needed for the given quantity of bids or
 * the amount of lamports the pool would receive if the given quantity of NFTs would sell
 * @param pool Pool or PoolConfig with priceOffset
 * @param quantity Amount of bids or listings (depending on @param side)
 * @param side TakerSide.Buy for Listings, TakerSide.Sell for Bids
 * @returns Amount of lamports needed
 */
export declare function calculateAmountForQuantity({ pool, quantity, side, }: {
    pool: Pick<Pool, 'config' | 'priceOffset'>;
    quantity: number;
    side: TakerSide;
}): number;
/**
 * Returns the amount of bids a pool or a pool config
 * can bid for given its available balance (MAX 1000)
 * @param pool Pool or PoolConfig with additional fields needed for maxTakerSellCount
 * @param availableLamports Amount of Lamports available to the pool
 * @returns Number of Bids (MAX 1000)
 */
export declare function getAmountOfBids({ pool, availableLamports, }: {
    pool: Pick<Pool, 'config' | 'priceOffset' | 'maxTakerSellCount' | 'sharedEscrow'>;
    availableLamports: number | bigint;
}): number;
/**
 * Either returns the current ask price (price the pool currently sells its held NFTs for) or null (if the pool doesn't sell anymore)
 * @param pool Pool or PoolConfig with additional parameters
 * @param royaltyFeeBps Creator royalties in BPS
 * @param extraOffset Additional offset to calculate further prices (> 0)
 * @param excludeMMFee Whether to exclude the MM fee in the returned price
 * @returns Current Ask Price OR null
 */
export declare function getCurrentAskPrice({ pool, royaltyFeeBps, extraOffset, excludeMMFee, }: {
    pool: Pick<Pool, 'config' | 'nftsHeld' | 'priceOffset' | 'maxTakerSellCount' | 'sharedEscrow'>;
    royaltyFeeBps: number;
    extraOffset?: number;
    excludeMMFee?: boolean;
}): number | null;
/**
 * Either returns the current bid price (price the pool bids for) or null if the pool does not bid anymore (e.g. if the pool does not have sufficient funds left)
 * @param pool Pool or PoolConfig with additional parameters
 * @param availableLamports Available Balance to the Pool
 * @param royaltyFeeBps Creator royalties in BPS
 * @param extraOffset Additional offset to calculate further prices (> 0)
 * @param excludeMMFee Whether to exclude the MM fee in the returned price
 * @returns Current Bid Price OR null
 */
export declare function getCurrentBidPriceSync({ pool, availableLamports, royaltyFeeBps, extraOffset, excludeMMFee, }: {
    pool: Pick<Pool, 'config' | 'priceOffset' | 'maxTakerSellCount' | 'sharedEscrow'>;
    availableLamports: number | bigint;
    royaltyFeeBps: number;
    extraOffset?: number;
    excludeMMFee?: boolean;
}): number | null;
/**
 * Either returns the current bid price (price the pool bids for) or null if the pool does not bid anymore (e.g. if the pool does not have sufficient funds left).
 * Fetches the current escrow balance - account rent if needed via given RPC
 * @param rpc Rpc proxy instance
 * @param pool Pool or PoolConfig with additional parameters
 * @param royaltyFeeBps Creator royalties in BPS
 * @param extraOffset Additional offset to calculate further prices (> 0)
 * @param excludeMMFee Whether to exclude the MM fee in the returned price
 * @returns Current Bid Price OR null
 */
export declare function getCurrentBidPrice({ rpc, pool, royaltyFeeBps, extraOffset, excludeMMFee, }: {
    rpc: Rpc<GetAccountInfoApi & GetMinimumBalanceForRentExemptionApi>;
    pool: Pick<Pool, 'config' | 'owner' | 'amount' | 'priceOffset' | 'maxTakerSellCount' | 'sharedEscrow'>;
    royaltyFeeBps: number;
    extraOffset?: number;
    excludeMMFee?: boolean;
}): Promise<number | null>;
/**
 * Calculates the raw bid/ask price of a pool / pool config
 * @param pool Pool or PoolConfig with additional parameters
 * @param side TakerSide.Buy for getting Ask prices / TakerSide.Sell for getting Bid prices
 * @param royaltyFeeBps Creator royalties in BPS
 * @param extraOffset Additional offset to calculate further prices (> 0)
 * @param excludeMMFee Whether to exclude the MM fee in the returned price
 * @returns Resulting bid/ask price
 */
export declare function calculatePrice({ pool, side, royaltyFeeBps, extraOffset, excludeMMFee, }: {
    pool: Pick<Pool, 'config' | 'priceOffset'>;
    side: TakerSide;
    royaltyFeeBps: number;
    extraOffset?: number;
    excludeMMFee?: boolean;
}): number;
//# sourceMappingURL=helpers.d.ts.map